==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/sk-SK/admin/models/message.php <==
<?php

return array(

    'deleted' => 'Deleted asset model',
    'does_not_exist' => 'Model neexistuje.',
    'no_association' => 'WARNING! The asset model for this item is invalid or missing!',
    'no_association_fix' => 'This will break things in weird and horrible ways. Edit this asset now to assign it a model.',
    'assoc_users'	 => 'Tento model je použítý v jednom alebo viacerých majetkoch, preto nemôže byť odstránený. Prosím odstráňte príslušný majetok a skúste odstrániť znovu. ',
    'invalid_category_type' => 'The category must be an asset category.',

    'create' => array(
        'error'   => 'Model nebol vytovrený, prosím skúste znovu.',
        'success' => 'Model bol úspešne vytvorený.',
        'duplicate_set' => 'Model majetku s týmto názvom, výrobcom a číslom modelu už existuje.',
    ),

    'update' => array(
        'error'   => 'Model nebol upravený, prosím skúste znovu',
        'success' => 'Model bol úspešne upravený.',
    ),

    'delete' => array(
        'confirm'   => 'Ste si istý, že chcete odstrániť tento model majetku?',
        'error'   => 'Pri odstraňovaní modelu sa vyskytla chyba. Skúste prosím znovu.',
        'success' => 'Model bol úspešne odstránený.'
    ),

    'restore' => array(
        'error'   		=> 'Model nebol obnovený, prosím skúste znovu',
        'success' 		=> 'Model bol obnovený úspešne.'
    ),

    'bulkedit' => array(
        'error'   		=> 'Neboli zmenené žiadne polia, preto nebolo nič aktualizované.',
        'success' 		=> 'Model successfully updated. |:model_count models successfully updated.',
        'warn'          => 'You are about to update the properties of the following model:|You are about to edit the properties of the following :model_count models:',

    ),

    'bulkdelete' => array(
        'error'   		    => 'Neboli vybrané ziadne modely, preto nebolo nič odmazané.',
        'success' 		    => 'Model deleted!|:success_count models deleted!',
        'success_partial' 	=> ':success_count model(y) odstránené, avšak :fail_count nebolo možné odstrániť pretože stále majú priradené majetky.'
    ),

);

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/sk-SK/admin/models/message.php <==
<?php

return array(

    'deleted' => 'Odstránený model majetku',
    'does_not_exist' => 'Model neexistuje.',
    'no_association' => 'VAROVANIE! Model majetku pre túto položku je neplatný alebo neexistuje!',
    'no_association_fix' => 'Tento stav môže spôsobiť nepredvídateľné problémy. Priraďte danému majetku správny model.',
    'assoc_users'	 => 'Tento model je použítý v jednom alebo viacerých majetkoch, preto nemôže byť odstránený. Prosím odstráňte príslušný majetok a skúste odstrániť znovu. ',
    'invalid_category_type' => 'Táto kategória musí byť kategóriou majetku.',

    'create' => array(
        'error'   => 'Model nebol vytovrený, prosím skúste znovu.',
        'success' => 'Model bol úspešne vytvorený.',
        'duplicate_set' => 'Model majetku s týmto názvom, výrobcom a číslom modelu už existuje.',
    ),

    'update' => array(
        'error'   => 'Model nebol upravený, prosím skúste znovu',
        'success' => 'Model bol úspešne upravený.',
    ),

    'delete' => array(
        'confirm'   => 'Ste si istý, že chcete odstrániť tento model majetku?',
        'error'   => 'Pri odstraňovaní modelu sa vyskytla chyba. Skúste prosím znovu.',
        'success' => 'Model bol úspešne odstránený.'
    ),

    'restore' => array(
        'error'   		=> 'Model nebol obnovený, prosím skúste znovu',
        'success' 		=> 'Model bol obnovený úspešne.'
    ),

    'bulkedit' => array(
        'error'   		=> 'Neboli zmenené žiadne polia, preto nebolo nič aktualizované.',
        'success' 		=> 'Model bol úspešne upravený. |:model_count modelov bolo úspešne upravených.',
        'warn'          => 'Chystáte sa upraviť nastavenia nasledovného modelu:|Chystáte sa upraviť nastavenia nasledovných :model_count modelov:',

    ),

    'bulkdelete' => array(
        'error'   		    => 'Neboli vybrané ziadne modely, preto nebolo nič odmazané.',
        'success' 		    => 'Model zmazaný!|:success_count_models modelov zmazaných!',
        'success_partial' 	=> ':success_count model(y) odstránené, avšak :fail_count nebolo možné odstrániť pretože stále majú priradené majetky.'
    ),

);
